@@ -10,7 +10,7 @@ dockerfile_commands.append("COPY requirements.txt .")
 dockerfile_commands.append("RUN pip install --no-cache-dir -r requirements.txt")
 dockerfile_commands.append("COPY . .")
 
-def create_docker_file(imageTag: str, mainfile:str ):
+def create_deploy_docker_image(imageTag: str, mainfile:str ):
     # Define the base image and working directory
     base_image = "python:3.9-slim-buster"
     workdir = "/app"
@@ -71,6 +71,7 @@ def apply_yaml(Module, imageTag:str):
         yaml.dump(data, f)
     
 def main():
+    print("v0.0.5.2")
     # Create an ArgumentParser object
     parser = argparse.ArgumentParser()
 
@@ -80,9 +81,9 @@ def main():
 
     # Parse the command line arguments
     args = parser.parse_args()
-    mainfile = args.main_file
+    mainfilepath = args.main_file
     
-    module_name = mainfile[:-3]
+    module_name = mainfilepath[:-3]
     module_name = module_name.replace("/", ".")
     module_name = module_name.lstrip('.')
     
@@ -94,10 +95,13 @@ def main():
         M = module.create_module()
         
         imageTag = username + "/" + M.name + ":" + M.version
-        
-        create_docker_file(imageTag, module_name)
         apply_yaml(M, imageTag)
-        print(f"{mainfile} processed successfully")
+        
+        dirname = os.path.dirname(mainfilepath)
+        os.chdir(dirname)
+        create_deploy_docker_image(imageTag, module_name)
+        
+        print(f"{mainfilepath} processed successfully")
         
     except Exception as e:
         print(e)
